#!/bin/bash

# Input XYZ File
XYZFILE=./EX1202L2_DIVE13_GMTBATHY_25m.TXT

# Input file resolution (e=meter)
MBRES=30e

# INPUT ROV Trackline data
RAWTRACKFILE=./EX1202L2_DIVE13_RovTrack1Hz.csv

# CruiseID (i.e. EX1202L2)
CRUISE_ID=EX1202L2

# DIVE_NUM (i.e 01)
DIVE_NUM=13

# DIVE_DATE (yyyymmdd, i.e. 12020320)
DIVE_DATE=20120402

# Plot Title (i.e. EX1202L2: DIVE01 - 2012-03-20)
TITLE=`gawk -v date=${DIVE_DATE} -v num=${DIVE_NUM} -v cruise=${CRUISE_ID} 'BEGIN{printf "%s\\\072 DIVE %s - %s-%s-%s", cruise, num, substr(date,1,4),substr(date,5,2),substr(date,7,2)}'`

# Output directory
OUTPUTDIR=.

# Output pdf map filename (i.e. EX1202L2_DIVE01_20120320.pdf)
OUTPUT_PDF=${CRUISE_ID}_DIVE${DIVE_NUM}_${DIVE_DATE}_DIVEMAP.pdf

# Output ps map filename (ps)
OUTPUT=${CRUISE_ID}_DIVE${DIVE_NUM}_${DIVE_DATE}_DIVEMAP.ps

# Temp gridfile
GRDFILE=${OUTPUTDIR}/output.grd

# Temp gridgradientfile
GRADFILE=${OUTPUTDIR}/gridgradient.grad

# Temp color palette file
CPTFILE=${OUTPUTDIR}/output.cpt

# Temp psxy-formatted ROV Trackline file
TRACKLINE=${OUTPUTDIR}/track.xy

# Temp pstext-formatted time tick file
TIMETICKS=${OUTPUTDIR}/timeticks.d

# Build temp psxy-formatted ROV trackline file
gawk -F, '{printf "%s %s\n", $5, $4 }' ${RAWTRACKFILE} > ${TRACKLINE}

# Build temp pstext-formatted time tick file
ANGLE=45
gawk -F, -v angle=${ANGLE} '{if ( NR == 2 ) printf "%s %s 10 %s 0 ML Start: %s\n", $5, $4, angle, strftime("%D %H:%M", $3) } {if (( NR > 2 ) && ( int($3)%3600 == 0)) printf "%s %s 10 %s 0 ML %s\n", $5, $4, angle, strftime("%H:%M", $3) }' ${RAWTRACKFILE} > ${TIMETICKS}
tail -n1 ${RAWTRACKFILE} | gawk -F, -v angle=${ANGLE} '{printf "%s %s 10 %s 0 ML End: %s\n", $5, $4, angle, strftime("%D %H:%M", $3) }' >> ${TIMETICKS}

# Clear pre-existing gmtdefaults file
rm ./.gmtdefaults4

# Set map bounds based on ROV trackline min/max data
R=`minmax -I0.0025 -H ${TRACKLINE}`

# Grid input XYZ data
xyz2grd ${XYZFILE} ${R} -Ddegree/degree/meters/1/0/"EM302 Multibeam Data"/"WGS84 Ellipsoid used" -G${GRDFILE} -I${MBRES}

# Build gradient file
grdgradient ${GRDFILE} -A0 -M -Nt -G${GRADFILE}

# Build color palette file from what was used by the EX Mapping team
grd2cpt ${GRDFILE} -R -S-4200/-10/10 > ${CPTFILE}

### Begin map making ###
# Set Portrait/Landscape
gmtset PAGE_ORIENTATION PORTRAIT

# Set the border style for the dive map to "fancy"
gmtset BASEMAP_TYPE FANCY

# Build basedmap with grid data
psbasemap -R -JM4i -Ba.005f.0025:."${TITLE}": -K  -U -X2i -Y1i > ${OUTPUTDIR}/${OUTPUT} 

grdimage ${GRDFILE} -R -J -C${CPTFILE} -Q -K -O >> ${OUTPUTDIR}/${OUTPUT} 

# Add contour lines
grdcontour ${GRDFILE} -R -J -O -K -C20 -A20+s8 -Gd1.5i -S10 >> ${OUTPUTDIR}/${OUTPUT}

# Add ROV trackline (black)
psxy ${TRACKLINE} -H -R -J -Sc0.025c -Gblack -O -K >> ${OUTPUTDIR}/${OUTPUT}

# Add time ticks (white)
pstext ${TIMETICKS} -R -J -Gwhite -O -K >> ${OUTPUTDIR}/${OUTPUT}

# Add coastline data (high-resolution)
pscoast -R -J -G96 -Dh -O -K -P >> ${OUTPUTDIR}/${OUTPUT}

# Add color scale
psscale -C${CPTFILE} -D5i/4.5i/5i/0.25i -B1000/:meters: -O -K >> ${OUTPUTDIR}/${OUTPUT}

### Begin inset map making ###
# Set the border style for the inset map to "plain"
gmtset BASEMAP_TYPE PLAIN

# Set the bounds for the inset map
R="-R-91/-85/27/31"

# Plot the base map
psbasemap ${R} -JM1.5i -O -K -G255 -X.1i -Y7.8i -Bnesw >> ${OUTPUTDIR}/${OUTPUT}

# Add coastline
pscoast -R -J -G96 -Di -O -K >> ${OUTPUTDIR}/${OUTPUT}

# Add a star where the dive started
head -n2 ${TRACKLINE} | psxy -H -R -J -Sa0.5c -Gred -O >> ${OUTPUTDIR}/${OUTPUT}

#convert ps to pdf
pstopdf ${OUTPUTDIR}/${OUTPUT} -o ${OUTPUTDIR}/${OUTPUT_PDF}

# Cleanup (rm intermediate files)
rm ${OUTPUTDIR}/${OUTPUT}
rm ${GRDFILE}
rm ${GRADFILE}
rm ${CPTFILE}
rm ${TRACKLINE}
rm ${TIMETICKS}